package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.RegisterParentsStudent;
import org.apache.ibatis.annotations.Param;

/**
 * 注册-家长-学生Mapper接口
 * 
 * @author ruoyi
 * @date 2023-05-25
 */
public interface RegisterParentsStudentMapper 
{
    /**
     * 查询注册-家长-学生
     * 
     * @param id 注册-家长-学生主键
     * @return 注册-家长-学生
     */
    public RegisterParentsStudent selectRegisterParentsStudentById(Long id);

    /**
     * 查询注册-家长-学生列表
     * 
     * @param registerParentsStudent 注册-家长-学生
     * @return 注册-家长-学生集合
     */
    public List<RegisterParentsStudent> selectRegisterParentsStudentList(RegisterParentsStudent registerParentsStudent);

    /**
     * 新增注册-家长-学生
     * 
     * @param registerParentsStudent 注册-家长-学生
     * @return 结果
     */
    public int insertRegisterParentsStudent(RegisterParentsStudent registerParentsStudent);

    /**
     * 修改注册-家长-学生
     * 
     * @param registerParentsStudent 注册-家长-学生
     * @return 结果
     */
    public int updateRegisterParentsStudent(RegisterParentsStudent registerParentsStudent);

    /**
     * 删除注册-家长-学生
     * 
     * @param id 注册-家长-学生主键
     * @return 结果
     */
    public int deleteRegisterParentsStudentById(Long id);

    /**
     * 批量删除注册-家长-学生
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRegisterParentsStudentByIds(Long[] ids);
    /**
     * 批量删除注册-家长-学生(只删除审核未通过的)
     *
     * @param parentsId 家长id
     * @return 结果
     */
    void deleteRegisterParentsStudentByParentsId(Long parentsId);

    List<RegisterParentsStudent> selectRegisterParentsStudentListByTime(@Param("monthFirst") String monthFirst, @Param("classIds")List<Long> classIds);
}
